==> haskell-skylighting-core-0.14-15-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-core
version:              0.14
visibility:           public
id:                   skylighting-core-0.14-Bf0XKxp0R6GJO8a8AwQQfp
key:                  skylighting-core-0.14-Bf0XKxp0R6GJO8a8AwQQfp
license:              BSD-3-Clause
copyright:            (C) 2016-2018 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  c4a5ce08a4b7c7b0e7de17bdee7918a6
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14-Bf0XKxp0R6GJO8a8AwQQfp
depends:
    aeson-2.1.2.1-3YQjfXPQMsb4U9de9kBzUF
    attoparsec-0.14.4-Bi4fbguKdku98LXMy0bDoK base-4.16.4.0
    base64-bytestring-1.2.1.0-6ICZKEZtNauKUlSfxjYXGw binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-GWeOjNQL6o11YPoz7mZGER
    colour-2.3.6-IwE0zgnqjD2KAyPru21evK containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-CqIHKdkgiB2klcxc5dxay text-1.2.5.0 transformers-0.5.6.2
    utf8-string-1.0.2-9i4m1tpDbmh81tMCrQ25jI
    xml-conduit-1.9.1.3-2x4d78AN6G9sdWplW1Etj

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-core-0.14-17-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 skylighting-core
version:              0.14
visibility:           public
id:                   skylighting-core-0.14-Kfh3AcVHAd163hiBSCHbh7
key:                  skylighting-core-0.14-Kfh3AcVHAd163hiBSCHbh7
license:              BSD-3-Clause
copyright:            (C) 2016-2018 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             syntax highlighting library
description:
    Skylighting is a syntax highlighting library.
    It derives its tokenizers from XML syntax
    definitions used by KDE'\''s KSyntaxHighlighting
    framework, so any syntax supported by that
    framework can be added. An optional command-line
    program is provided.
    Skylighting is intended to be the successor to
    highlighting-kate.
    This package provides the core highlighting
    functionality under a permissive license. It also
    bundles XML parser definitions licensed under the
    GPL.

category:             Text
abi:                  1bd7c2526b8a3d2e51daa36c36a929bb
exposed:              True
exposed-modules:
    Skylighting.Core Skylighting.Loader Skylighting.Parser
    Skylighting.Regex Skylighting.Styles Skylighting.Tokenizer
    Skylighting.Types

hidden-modules:
    Regex.KDE Regex.KDE.Regex Regex.KDE.Compile Regex.KDE.Match

import-dirs:          /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/skylighting-core-0.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-core
hs-libraries:         HSskylighting-core-0.14-Kfh3AcVHAd163hiBSCHbh7
depends:
    aeson-2.1.2.1-JfeHvfgWyvGEUkRmM0msk9
    attoparsec-0.14.4-FU2s2IQbUKDB3KL4mTNthi base-4.16.4.0
    base64-bytestring-1.2.1.0-Emr26XEx0H73b2OnZgz4Hk binary-0.8.9.0
    bytestring-0.11.4.0 case-insensitive-1.2.1.0-A5LsT2Hev12E0IVM96Pcon
    colour-2.3.6-IwE0zgnqjD2KAyPru21evK containers-0.6.5.1
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2
    safe-0.3.21-6vX5iZ5iJJx5vecLqZTKv8 text-1.2.5.0
    transformers-0.5.6.2 utf8-string-1.0.2-CndrelvclEbJyymwdX0DqC
    xml-conduit-1.9.1.3-2iOa1EoOAw0GwKD8WBefNZ

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-core/html/skylighting-core.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-core/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
